# Generated by roxygen2: do not edit by hand

S3method(print,boilerplate_files)
S3method(print,boilerplate_health)
export(boilerplate_add_bibliography)
export(boilerplate_add_entry)
export(boilerplate_appendix)
export(boilerplate_batch_clean)
export(boilerplate_batch_edit)
export(boilerplate_batch_edit_multi)
export(boilerplate_check_health)
export(boilerplate_copy_bibliography)
export(boilerplate_copy_from_project)
export(boilerplate_discussion)
export(boilerplate_export)
export(boilerplate_find_chars)
export(boilerplate_generate_measures)
export(boilerplate_generate_text)
export(boilerplate_get_entry)
export(boilerplate_import)
export(boilerplate_init)
export(boilerplate_list_files)
export(boilerplate_list_paths)
export(boilerplate_list_projects)
export(boilerplate_measures)
export(boilerplate_measures_report)
export(boilerplate_methods)
export(boilerplate_migrate_to_json)
export(boilerplate_path_exists)
export(boilerplate_rds_to_json)
export(boilerplate_remove_entry)
export(boilerplate_restore_backup)
export(boilerplate_results)
export(boilerplate_save)
export(boilerplate_sort_db)
export(boilerplate_standardise_measures)
export(boilerplate_template)
export(boilerplate_update_bibliography)
export(boilerplate_update_entry)
export(boilerplate_validate_references)
export(compare_rds_json)
export(validate_json_database)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(tools,toTitleCase)
importFrom(utils,download.file)
